function Abaqus2PhasefieldUEL_dynamic(inputPath,MatProp)
% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% !!!!!!!!!!!!!!!!!! --------- BETA Version --------- !!!!!!!!!!!!!!!!!!!!
%  When this script is used, it is the user's responsibility to check and
%                         interpret all results.
% !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
% 
% Abaqus2PhasefieldUEL adds the UEL option to an ABAQUS created input file
%             If the input file is created in the same order as discussed
%             in the tutorials (http://www.molnar-research.com/tutorials.html)
%             present MATLAB script finds the element definition and
%             multiplies it three times for the two UEL layers and the
%             post-processing UMAT layer.
%
%     More on the theory and implementation of the UEL to model diffuse 
%     fracture with phase-field can be found in our recent paper:
%     G. Molnar, A. Gravouil, R. Seghir, J. Rethore, An open-source Abaqus
%     implementation of the phase-field method to study the effect of plasticity
%     on the instantaneous fracture toughness in dynamic crack propagation
%     Computer Methods in Applied Mechanics and Engineering, 365, 113004 (2020)
%
%     https://www.sciencedirect.com/science/article/pii/S0045782520301882
%
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%     The script is not able to convert all types of input files, only the
%     ones created the right order discussed in these tutorials (e.g. the
%     mesh needs to be defined on the parts):
%        http://www.molnar-research.com/tutorials.html
%    !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
%               
%   Current version converts 2D triangular and square elements with
%    isotropic energy degradation function to UEL compatible input files
%
%  -----  INPUT variables are the following -------------------------------
% inputPath - is a string which point to the input file created by ABAQUS,
%				if left blank [], the script opens an inquiry
%
% MatProp - is an array of (x,12) values containing materials parameters
%           both for the stress and phase field elements, where x is the
%           number of different materials used:
%
%           MatProp(:,1) - Young's modulus
%           MatProp(:,2) - Poisson's ratio
%           MatProp(:,3) - Yield stress (von Mises)
%           MatProp(:,4) - Hardening modulus
%           MatProp(:,5) - Critical strain
%           MatProp(:,6) - thickness of the element (for plane strain case  
%                        it is automatically set to 1.0)
%           MatProp(:,7) - Density (rho)
%           MatProp(:,8) - Length scale parameter for the phase function
%           MatProp(:,9) - Fracture surface energy release rate
%           MatProp(:,10) - Anisotropic energy switch
%           MatProp(:,11) - Plasticity switch
%           MatProp(:,12) - Elastic treshold switch
% -------------------------------------------------------------------------
%
% BASIC structure of the script:
% 0) Loading input variables
% 1) Start copying original input file into the new one
% 2) When the beginning of the element definition section is found
%    (*Element) it stops copying and starts uploading elements into ElMat
%    array.
% 3) Parallel it writes the first layer of finite elements
% 4) When ready it replicates the two additional layers
% 5) Creates element sets and assigns material properties
% 6) Continues copying the original input file until the end of the assembly
%	 part. Here the script adds an additional element set summing up all
%    the UMAT elements.
% 7) Then it finishes the with the simulation steps, adding always a field
%    output request for the SDVs
% -------------------------------------------------------------------------
%

narginLoc=nargin;

if narginLoc<2
    if narginLoc==0
% ---------------- Asking for the input file -------------------
        [FileName,PathName,FilterIndex] = uigetfile('*.inp');
        inputPath=[PathName FileName];
    end
    if isa(inputPath,'char')~=1
        error('Provide a valid input file.')
    end
end

if length(MatProp(1,:))<12
    error('Not enought material properties are given.')
end
if length(MatProp(1,:))>12
    error('Too much material properties are given.')
end
    
if isempty(inputPath)==1
    [FileName,PathName,FilterIndex] = uigetfile('*.inp');
    inputPath=[PathName FileName];
end

% ---------------- Uploaing material properties -------------------
Ymod=MatProp(:,1);
nu=MatProp(:,2);
Ystress=MatProp(:,3);
Hmod=MatProp(:,4);
epscr=MatProp(:,5);
thck=MatProp(:,6);
dens=MatProp(:,7);
anisoswt=MatProp(:,10);
plswt=MatProp(:,11);

lc=MatProp(:,8);
gc=MatProp(:,9);
elswt=MatProp(:,12);


% ---------------- Initializing output file -------------------
inputName=inputPath;
output=[inputPath(1:end-4) '_UEL.inp'];

fid=fopen(inputName,'rt');
fout1 = fopen(output, 'wt');
a=fgets(fid);

cnt=0;

% ---------------- Sart reading input file -------------------
cntE=1;
while(ischar(a))

% ------ Repeating nodes ------
    while(ischar(a))
        if strfind(a,'*Element')~=0
            break
        end
        fprintf(fout1,a);    
        a=fgets(fid);
    end

    a=fgets(fid);

% ------ Defintion of UEL types ------
    if length(str2num(a))==4
       % triangular elements 
        fprintf(fout1,['***************************************************************\n']);
        fprintf(fout1,['*User element, nodes=3, type=U1, properties=11, coordinates=2, VARIABLES=34\n']);
        fprintf(fout1,['1,2\n']);
        fprintf(fout1,['*********************** TRIANGULAR ****************************\n']);
        fprintf(fout1,['*User element, nodes=3, type=U3, properties=4, coordinates=2, VARIABLES=5\n']);
        fprintf(fout1,['3\n']);
        NnodeE(cntE)=3;
    else
       % rectangular elements 
        fprintf(fout1,['***************************************************************\n']);
        fprintf(fout1,['*User element, nodes=4, type=U2, properties=11, coordinates=2, VARIABLES=120\n']);
        fprintf(fout1,['1,2\n']);
        fprintf(fout1,['*********************** RECTENGULAR ***************************\n']);
        fprintf(fout1,['*User element, nodes=4, type=U4, properties=4, coordinates=2, VARIABLES=12\n']);
        fprintf(fout1,['3\n']);
        NnodeE(cntE)=4;
    end



% ------ Uploading original mesh ------
    cnt=0;
    while isempty(strfind(a,'*Nset,')) && isempty(strfind(a,'*Element,'))
        cnt=cnt+1;
        ElMat{cntE}(cnt,:)=str2num(a);
        a=fgets(fid);
    end
    nElem(cntE)=length(ElMat{cntE}(:,1));

    fprintf(fout1,['***************************************************************\n']);

    if isempty(strfind(a,'*Element,'))==0
        cntE=cntE+1;
    else
        break
    end
end

TypeElem=zeros(sum(nElem),1);
for i=1:cntE
    TypeElem(ElMat{i}(:,1))=NnodeE(i);
end

% ------ All elements ------
nElemAll=sum(nElem);

% Uploading Elsets for different materials
cnt2=1;
while isempty(strfind(a,'** Section'))
   while isempty(strfind(a,'*Elset,'))
       a=fgets(fid);
   end
   bin=strfind(a,'elset=');
   Ename=a(bin+6:end-1);
   if isempty(strfind(Ename,','))==0
      bin=strfind(Ename,',');
      Ename=Ename(1:bin-1);
   end
   ElstName{cnt2}=Ename;
%   fprintf(fout1,a);
   ElSeT{cnt2}{1}=a;
   a=fgets(fid);
   cnt3=2;
   while isempty(strfind(a,'** Section:')) && isempty(strfind(a,'*Nset,'))
       ElSeT{cnt2}{cnt3}=a;
%       fprintf(fout1,a);
       a=fgets(fid);
       cnt3=cnt3+1;
   end
   Nline(cnt2)=cnt3-1;
   cnt2=cnt2+1;
end
%fprintf(fout1,['***************************************************************\n']);

nMat=length(ElstName);

% Converting uploaded strings to actual numbers
for i=1:nMat
    clear noLoc
   if isempty(strfind(ElSeT{i}{1},'generate'))
       noLoc=[];
       for j=2:length(ElSeT{i})
           noLoc=[noLoc,str2num(ElSeT{i}{j})];
       end
       genopt(i)=0;
   else
       noLoc=str2num(ElSeT{i}{2});
       genopt(i)=1;       
   end
   noElem{i}=noLoc;
   if isempty(strfind(ElSeT{i}{1},'uel_'))
      isuel(i)=0;
   else
      isuel(i)=1;
   end
end

if nnz(isuel)<1
    error('No UEL sets were found.')
end

% Choosing element sets for UELs and reordering them accordingly
% we need to have the UELs first, then the rest of the model
allUEL=[];
allnonUEL=[];
for i=1:nMat
    if isuel(i)==1
        if genopt(i)==0
            allUEL=[allUEL, noElem{i}];
        else
            allUEL=[allUEL, noElem{i}(1):noElem{i}(3):noElem{i}(2)];
        end
    else
        if genopt(i)==0
            allnonUEL=[allnonUEL, noElem{i}];
        else
            allnonUEL=[allnonUEL, noElem{i}(1):noElem{i}(3):noElem{i}(2)];
        end        
    end
end

OrderElemUELT=intersect(find(TypeElem==3),allUEL);
TriUEL=length(OrderElemUELT);
OrderElemUELQ=intersect(find(TypeElem==4),allUEL);
QuadUEL=length(OrderElemUELQ);
noUEL=TriUEL+QuadUEL;

OrderElemnonUELT=intersect(find(TypeElem==3),allnonUEL);
TrinonUEL=length(OrderElemnonUELT);
OrderElemnonUELQ=intersect(find(TypeElem==4),allnonUEL);
QuadnonUEL=length(OrderElemnonUELQ);

if TriUEL>0
    locPosType=find(NnodeE==3);
    [~,idxT]=intersect(ElMat{locPosType}(:,1),OrderElemUELT);
end
if QuadUEL>0
    locPosType=find(NnodeE==4);
    [~,idxQ]=intersect(ElMat{locPosType}(:,1),OrderElemUELQ);
end
if TrinonUEL>0
    locPosType=find(NnodeE==3);
    [~,idxnT]=intersect(ElMat{locPosType}(:,1),OrderElemnonUELT);
end
if QuadnonUEL>0
    locPosType=find(NnodeE==4);
    [~,idxnQ]=intersect(ElMat{locPosType}(:,1),OrderElemnonUELQ);
end

cnt=1;
if TriUEL>0
    fprintf(fout1,['***************************************************************\n']);
    fprintf(fout1,['*Element, type=U1\n']);
    locPosType=find(NnodeE==3);
    for i=1:TriUEL
        j=idxT(i);
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        uelSS(OrderElemUELT(i))=cnt;
        cnt=cnt+1;
    end
end
if QuadUEL>0
    fprintf(fout1,['***************************************************************\n']);
    fprintf(fout1,['*Element, type=U2\n']);
    locPosType=find(NnodeE==4);
    for i=1:QuadUEL
        j=idxQ(i);
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        uelSS(OrderElemUELQ(i))=cnt;
        cnt=cnt+1;
    end
end
if TriUEL>0
    fprintf(fout1,['***************************************************************\n']);
    fprintf(fout1,['*Element, type=U3\n']);
    locPosType=find(NnodeE==3);
    for i=1:TriUEL
        j=idxT(i);
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        uelPH(OrderElemUELT(i))=cnt;
        cnt=cnt+1;
    end
end
if QuadUEL>0
    fprintf(fout1,['***************************************************************\n']);
    fprintf(fout1,['*Element, type=U4\n']);
    locPosType=find(NnodeE==4);
    for i=1:QuadUEL
        j=idxQ(i);
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        uelPH(OrderElemUELQ(i))=cnt;
        cnt=cnt+1;
    end
end

% Normal elements and new element order
NewOrder=zeros(nElemAll,1);

if TriUEL>0
    fprintf(fout1,['********************* UMAT tri ***********************************\n']);
    fprintf(fout1,['*Element, type=CPE3\n']);
    locPosType=find(NnodeE==3);
    for i=1:TriUEL
        j=idxT(i);
        NewOrder(OrderElemUELT(i))=cnt;
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        cnt=cnt+1;
    end
end
if QuadUEL>0
    fprintf(fout1,['********************* UMAT quad ***********************************\n']);
    fprintf(fout1,['*Element, type=CPE4\n']);
    locPosType=find(NnodeE==4);
    for i=1:QuadUEL
        j=idxQ(i);
        NewOrder(OrderElemUELQ(i))=cnt;
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        cnt=cnt+1;
    end
end
    
   
if TrinonUEL>0
    fprintf(fout1,['********************* non UMAT tri ***********************************\n']);
    fprintf(fout1,['*Element, type=CPE3\n']);
    locPosType=find(NnodeE==3);
    for i=1:TrinonUEL
        j=idxnT(i);
        NewOrder(OrderElemnonUELT(i))=cnt;
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        cnt=cnt+1;
    end
end    

if QuadnonUEL>0
fprintf(fout1,['********************* non UMAT quad ***********************************\n']);
fprintf(fout1,['*Element, type=CPE4\n']);
    locPosType=find(NnodeE==4);
    for i=1:QuadnonUEL
        j=idxnQ(i);
        NewOrder(OrderElemnonUELQ(i))=cnt;
        fprintf(fout1,[num2str(cnt) ', ' num2str(ElMat{locPosType}(j,2:end-1),'%d, ') ' ' num2str(ElMat{locPosType}(j,end)) '\n']);
        cnt=cnt+1;
    end
end    

AllElem=cnt-1;

fprintf(fout1,['***************************************************************\n']);


% ------ Redefining element sets ------
for i=1:nMat
   if isuel(i)==0
       % ---------- Non-UEL sets --------
       if genopt(i)==0
          fprintf(fout1,ElSeT{i}{1});
          locvals=[];
          for j=2:length(ElSeT{i})
            locvals=[locvals str2num(ElSeT{i}{j})];
          end
          bnew=NewOrder(locvals)';
            nline=floor(length(bnew)/16);
            for j=1:nline
                fprintf(fout1,[num2str(bnew((j-1)*16+1:j*16),'%1.0i, ') '\n']);
            end
            str=num2str(bnew((nline*16)+1:end),'%1.0i, ');
            fprintf(fout1,[str(1:end-1) '\n']);
       else
          fprintf(fout1,ElSeT{i}{1});
          borig=str2num(ElSeT{i}{2});
          bnew=NewOrder(borig)';
          fprintf(fout1,[num2str(bnew(1)) ', ' num2str(bnew(2)) ', ' num2str(borig(3))  '\n']);
       end
   else
       % ---------- UEL sets --------
       if genopt(i)==0
          % Displacement elements 
          fprintf(fout1,ElSeT{i}{1});
          locvals=[];
          for j=2:length(ElSeT{i})
            locvals=[locvals str2num(ElSeT{i}{j})];
          end
          
          bnew=uelSS(locvals);
          nline=floor(length(bnew)/16);
          for j=1:nline
            fprintf(fout1,[num2str(bnew((j-1)*16+1:j*16),'%1.0i, ') '\n']);
          end
          str=num2str(bnew((nline*16)+1:end),'%1.0i, ');
          fprintf(fout1,[str(1:end-1) '\n']);
          
          % Phase field elements 
          fprintf(fout1,[ElSeT{i}{1}(1:end-1) '_PH\n']);
          bnew=uelPH(locvals);
          nline=floor(length(bnew)/16);
          for j=1:nline
            fprintf(fout1,[num2str(bnew((j-1)*16+1:j*16),'%1.0i, ') '\n']);
          end
          str=num2str(bnew((nline*16)+1:end),'%1.0i, ');
          fprintf(fout1,[str(1:end-1) '\n']);   
     else
          % Displacement elements 
          fprintf(fout1,ElSeT{i}{1});
          borig=str2num(ElSeT{i}{2});
          bnew=uelSS(borig);
          fprintf(fout1,[num2str(bnew(1)) ', ' num2str(bnew(2)) ', ' num2str(borig(3))  '\n']);
          
          % Phase field elements
          fprintf(fout1,['*Elset, elset=' ElstName{i} '_PH, generate\n' ]);
          borig=str2num(ElSeT{i}{2});
          bnew=uelPH(borig);
          fprintf(fout1,[num2str(bnew(1)) ', ' num2str(bnew(2)) ', ' num2str(borig(3))  '\n']);          
          
       end
   end
end

if noUEL>0
      fprintf(fout1,['*Elset, elset=umatelem, generate\n' ]);
      fprintf(fout1,[num2str(noUEL*2+1) ', ' num2str(noUEL*3)   ', 1\n']);
end
   
% ------ Sets and material properties ------
fprintf(fout1,['***************************************************************\n']);
fprintf(fout1,['********************** ASSIGNING MATERIAL PROP ****************\n']);
fprintf(fout1,['***************************************************************\n']);
   
if length(Ymod)<nnz(isuel)
    error('Model contains more materials. Provide more material properties!')
end

k=1;
for kset=find(isuel==1)
    fprintf(fout1,['*Uel property, elset=' ElstName{kset} '\n']);
    fprintf(fout1,[num2str(Ymod(k)) ', ' num2str(nu(k)) ', ' num2str(Ystress(k)) ', ' num2str(Hmod(k)) ', ' num2str(epscr(k)) ', ' num2str(thck(k)) ', ' num2str(dens(k)) ', ' num2str(anisoswt(k)) ',\n' num2str(plswt(k)) ', ' num2str(lc(k)) ', ' num2str(gc(k)) '\n']);
    k=k+1;
end
fprintf(fout1,['**E, nu, Y, H, eps_cr, h, rho, anisoswt,\n**plswt, lc, gc\n']);

fprintf(fout1,['***************************************************************\n']);
k=1;
for kset=find(isuel==1)
    fprintf(fout1,['*Uel property, elset=' ElstName{kset} '_PH\n']);
    fprintf(fout1,[num2str(lc(k)) ', ' num2str(gc(k)) ', ' num2str(thck(k)) ', ' num2str(elswt(k)) '\n']);
    k=k+1;
end
fprintf(fout1,['**lc, gc, h, elswt\n']);
fprintf(fout1,['***************************************************************\n']);

a=fgets(fid);

while ~contains(a,'*End Part')
    if ~contains(a,'uel')==0
        UMATname=a(strfind(a,'material=')+9:end-1);
        a=fgets(fid);        
    else
        fprintf(fout1,a);        
    end
    a=fgets(fid);
end

fprintf(fout1,['*Solid Section, elset=umatelem, material=' UMATname '\n1.0\n']);

while(ischar(a))
    if strfind(a,'*Instance, name=')~=0
        break
    end
    fprintf(fout1,a);    
    a=fgets(fid);
end

InstanceName=a(strfind(a,'*Instance, name=')+16:strfind(a,', part=')-1);


while(ischar(a))
    if strfind(a,'*Elset')~=0
        if strfind(a,'generate')~=0
            a = strrep(a,', generate','');
            fprintf(fout1,a);
            a=fgets(fid);
            b=str2num(a);
            bnew=NewOrder(b(1):b(3):b(2))';
            nline=floor(length(bnew)/16);
            for i=1:nline
                fprintf(fout1,[num2str(bnew((i-1)*16+1:i*16),'%1.0i, ') '\n']);
            end
            str=num2str(bnew((nline*16)+1:end),'%1.0i, ');
            fprintf(fout1,[str(1:end-1) '\n']);
            a=fgets(fid);
        else
            fprintf(fout1,a);
            a=fgets(fid);
            while ~contains(a,'*')
                b=str2num(a);
                b=NewOrder(b)';
                fprintf(fout1,[num2str(b,'%1.0i, ') '\n']);
                a=fgets(fid);
            end
        end
    else
        if strfind(a,'*End Assembly')~=0
            break
        end
        fprintf(fout1,a);    
        a=fgets(fid);
    end
end


while(ischar(a))
    if strfind(a,'*End Assembly')~=0
        break
    end
    fprintf(fout1,a);    
    a=fgets(fid);
end

fprintf(fout1,['**\n']);

fprintf(fout1,['*Elset, elset=umatelem, instance=' InstanceName ', generate\n']);
fprintf(fout1,[num2str(noUEL*2+1) ', ' num2str(noUEL*3) ', 1\n']);
fprintf(fout1,['*Elset, elset=allelem, instance=' InstanceName ', generate\n']);
fprintf(fout1,[num2str(noUEL*2+1) ', ' num2str(AllElem) ', 1\n']);
fprintf(fout1,['**\n*End Assembly\n']);
fprintf(fout1,['***************************************************************\n']);

a=fgets(fid);

while(ischar(a))
    while(ischar(a))
        if strfind(a,'*Output, field')~=0
            while(ischar(a))
                if contains(a,'*Element Output')
                    fprintf(fout1,[a(1:end-1) ', elset=allelem\n']);    
                    a=fgets(fid);
                elseif strfind(a,'*Output, history')~=0
                    break                
                else
                    fprintf(fout1,a);    
                    a=fgets(fid);
                end
            end
        end
        if  strfind(a,'*Output, history')~=0
            break
        end
        fprintf(fout1,a);    
        a=fgets(fid);
    end
    
    fprintf(fout1,['*element output, elset=umatelem\n']);
    fprintf(fout1,['SDV\n']);
    fprintf(fout1,['*Element Output, elset=umatelem, Position=Integration Points\n']);
    fprintf(fout1,['COORD, IVOL\n']);
    fprintf(fout1,['**\n']);
    fprintf(fout1,a);
    a=fgets(fid);
       
    while(ischar(a))
        if strfind(a,'*End Step')~=0
            break
        end
        fprintf(fout1,a);    
        a=fgets(fid);
    end
    fprintf(fout1,a);    
    a=fgets(fid);
    
end

fclose('all');

% --------------- Start modifying the UEL fortran file -------------------

% determining if the OS if Lunix, Windows of Mac
comp = computer;
if strfind(comp,'WIN')~=0
    comptype=1;     % windows
elseif strfind(comp,'LNX')~=0
    comptype=2;     % linux
elseif strfind(comp,'MAC')~=0
    comptype=3;     % mac
else
    comptype=input('Please provide OS type: 1 - Microsoft Windows; 2 - Linux; 3 - Apple Mac: ');     % asking user
    if comptype==1 || comptype==2 || comptype==3
    else
        comptype=input('Wrong type.\n Please provide OS type: 1 - Microsoft Windows; 2 - Linux; 3 - Apple Mac: ');     % asking user
        if comptype==1 || comptype==2 || comptype==3
        else
        error('Wrong type. Try again.')
    end
    end
end

fullp=mfilename('fullpath');

if comptype==1
    if isempty(fullp)~=1
        input2=[fullp(1:end-28) '\PhaseFieldUEL\C2D6e8P3e4_PL.for'];
    else
        fullp=matlab.desktop.editor.getActiveFilename;
        input2=[fullp(1:end-30) '\PhaseFieldUEL\C2D6e8P3e4_PL.for'];
    end
else
    if isempty(fullp)~=1
        input2=[fullp(1:end-28) '/PhaseFieldUEL/C2D6e8P3e4_PL.f'];
    else
        fullp=matlab.desktop.editor.getActiveFilename;
        input2=[fullp(1:end-30) '/PhaseFieldUEL/C2D6e8P3e4_PL.f'];
    end
end


if comptype==1
    output=[inputName(1:end-4) '_UEL_PE.for'];
else
    output=[inputName(1:end-4) '_UEL_PE.f'];
end

fid=fopen(input2,'rt');
fout1 = fopen(output, 'wt');
a=fgets(fid);

while(ischar(a))
    if strfind(a,'N_ELEM=')~=0
        strs=strfind(a,'N_ELEM=');
        ends=strs+6;
        a=[a(1:ends) num2str(noUEL) a(ends+2:end)];
    end
    fprintf(fout1,a);    
    a=fgets(fid);
end

fclose('all');

return
